import {Body, Controller, Get, Post, UploadedFiles, UseGuards, UseInterceptors} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";
import {MarketYourBusinessSectionCmsService} from './market-your-business-section-cms.service';
import {UpdateMarketYourBusinessSectionCmsDto} from './dto/update-market-your-business-section-cms.dto';

@Controller({path: 'market-your-business-section-cms', version: Constants.API_VERSION_1})
export class MarketYourBusinessSectionCmsController {
    constructor(private readonly service: MarketYourBusinessSectionCmsService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'image', maxCount: 1}
    ]))
    updateOrCreateData(
        @Body() dto: UpdateMarketYourBusinessSectionCmsDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
