import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {AboutPageContentRepository} from './about-page-content.repository';
import {CreateAboutPageContentDto} from './dto/create-about-page-content.dto';
import {UpdateAboutPageContentDto} from './dto/update-about-page-content.dto';
import {AboutPageContentEntity} from './entity/about-page-content.entity';

@Injectable()
export class AboutPageContentService {
    constructor(
        @InjectRepository(AboutPageContentRepository)
        private readonly repository: AboutPageContentRepository
    ) {
    }

    async create(dto: CreateAboutPageContentDto): Promise<AboutPageContentEntity | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(): Promise<AboutPageContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdateAboutPageContentDto): Promise<AboutPageContentEntity | Error> {
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    }

    async findOne(id: string): Promise<AboutPageContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
