import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateAuthCommonDataDto} from "./dto/create-auth-common-data.dto";
import {UpdateAuthCommonDataDto} from "./dto/update-auth-common-data.dto";
import {AuthCommonData} from "./entities/auth-common-data.entity";

@EntityRepository(AuthCommonData)
export class AuthCommonDataRepository extends Repository<AuthCommonData> {
    async createEntity(dto: CreateAuthCommonDataDto): Promise<AuthCommonData | Error> {
        try {
            const entity = this.create({...dto});
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<AuthCommonData | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateAuthCommonDataDto): Promise<AuthCommonData | Error> {
        try {
            await this.update(id, {...dto});
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<AuthCommonData[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(AuthCommonData)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}