import {EntityRepository, getConnection, Repository} from "typeorm";
import {CareerLocation} from "./entities/career-location.entity";
import {CreateCareerLocationDto} from "./dto/create-career-location.dto";
import {UpdateCareerLocationDto} from "./dto/update-career-location.dto";

@EntityRepository(CareerLocation)
export class CareerLocationRepository extends Repository<CareerLocation> {
    async createEntity(dto: CreateCareerLocationDto): Promise<CareerLocation | Error> {
        try {
            const {
                name
            } = dto;
            const entity = this.create({
                name
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CareerLocation | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCareerLocationDto): Promise<CareerLocation | Error> {
        try {
            await this.update(id, {
                name: dto.name
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CareerLocation[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CareerLocation)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}