import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {HomePageBrandSectionService} from './home-page-brand-section.service';
import {CreateHomePageBrandSectionDto} from './dto/create-home-page-brand-section.dto';
import {UpdateHomePageBrandSectionDto} from './dto/update-home-page-brand-section.dto';
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";

@Controller({path: 'home-page-brand-section', version: Constants.API_VERSION_1})
export class HomePageBrandSectionController {
    constructor(private readonly service: HomePageBrandSectionService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'logo', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateHomePageBrandSectionDto,
        @UploadedFiles() files: {
            logo?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'logo', maxCount: 1}
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateHomePageBrandSectionDto,
        @UploadedFiles() files: {
            logo?: UploadedMulterFileI,
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
