import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateOfficeContentDto} from "./dto/create-office-content.dto";
import {UpdateOfficeContentDto} from "./dto/update-office-content.dto";
import {OfficeContentEntity} from "./entity/office-content.entity";

@EntityRepository(OfficeContentEntity)
export class OfficeContentRepository extends Repository<OfficeContentEntity> {

    async createEntity(dto: CreateOfficeContentDto): Promise<OfficeContentEntity | Error> {
        try {
            const {
                title,
                streetAddress,
                city,
                state,
                postalCode
            } = dto;
            const entity = this.create({
                title,
                streetAddress,
                city,
                state,
                postalCode
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<OfficeContentEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<OfficeContentEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateOfficeContentDto): Promise<OfficeContentEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(OfficeContentEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}