import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {FileUploadsService} from 'src/modules/file-uploads/file-uploads.service';
import {PressLinkContentRepository} from './press-link-content.repository';
import {CreatePressLinkContentDto} from './dto/create-press-link-content.dto';
import {PressLinkContentEntity} from './entity/press-link-content.entity';
import {UpdatePressLinkContentDto} from './dto/update-press-link-content.dto';
import {DoSpacesService} from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class PressLinkContentService {
    constructor(
        @InjectRepository(PressLinkContentRepository)
        private readonly repository: PressLinkContentRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpacesService: DoSpacesService
    ) {
    }

    async create(
        dto: CreatePressLinkContentDto,
        files: {
            icon?: UploadedMulterFileI,
        }
    ): Promise<PressLinkContentEntity | Error> {
        if (files && files.icon) {
            const url = await this.doSpacesService.uploadFile(files.icon[0], "PressLinkContent/");
            dto.icon = url.toString();
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async update(
        id: string,
        dto: UpdatePressLinkContentDto,
        files: {
            icon?: UploadedMulterFileI,
        }
    ): Promise<PressLinkContentEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        if (files && files.icon) {
            const url = await this.doSpacesService.uploadFile(files.icon[0], "PressLinkContent/");
            dto.icon = url.toString();
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }

    async findAll(): Promise<PressLinkContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<PressLinkContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
