import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateScheduleRoleDto} from "./dto/create-schedule-role.dto";
import {UpdateScheduleRoleDto} from "./dto/update-schedule-role.dto";
import {ScheduleRoleEntity} from "./entity/schedule-role.entity";

@EntityRepository(ScheduleRoleEntity)
export class ScheduleRoleRepository extends Repository<ScheduleRoleEntity> {

    async createEntity(dto: CreateScheduleRoleDto): Promise<ScheduleRoleEntity | Error> {
        try {
            const {
                roleName
            } = dto;
            const entity = this.create({
                roleName
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ScheduleRoleEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ScheduleRoleEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateScheduleRoleDto): Promise<ScheduleRoleEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(ScheduleRoleEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}