import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {Constants} from 'src/utils/constants';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {SocialLinkService} from './social-link.service';
import {CreateSocialLinkDto} from './dto/create-social-link.dto';
import {UpdateSocialLinkDto} from './dto/update-social-link.dto';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Controller({path: 'social-link', version: Constants.API_VERSION_1})

export class SocialLinkController {
    constructor(private readonly service: SocialLinkService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'icon', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateSocialLinkDto,
        @UploadedFiles() files: {
            icon?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'icon', maxCount: 1},
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateSocialLinkDto,
        @UploadedFiles() files: {
            icon?: UploadedMulterFileI,
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
