import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { EventScheduleRepository } from './event-schedule.repository';
import { EventScheduleEntity } from './entities/event-schedule.entity';
import { CreateEventScheduleDto } from './dto/createEventSchedule.dto';
import { UsersRepository } from '../users/user.repository';
import { UpdateEventScheduleDto } from './dto/updateEventSchedule.dto';

@Injectable()
export class EventScheduleService {
    constructor(
        @InjectRepository(UsersRepository)
        private readonly usersRepository: UsersRepository,
        @InjectRepository(EventScheduleRepository)
        private readonly eventScheduleRepository: EventScheduleRepository,
    ) {
    }

    async create(dto: CreateEventScheduleDto, user: any): Promise<EventScheduleEntity | Error> {
        const { guestEmail } = dto;
        const invitedUser: any = await this.usersRepository.findByEmailAddress(guestEmail);
        if (!invitedUser) {
            throw new HttpException(
                `User not found with the provided email address!`,
                HttpStatus.NOT_FOUND
            );
        } else if(invitedUser.id === user.id) {
            throw new HttpException(
                `You cannot schedule an event with you!`,
                HttpStatus.NOT_FOUND
            );
        }
        const { id: invitedUserId } = invitedUser;

        const createObj = {
            ...dto,
            invitedUserId: invitedUserId,
            invitedBy: user.id

        }
        const data = await this.eventScheduleRepository.createEntity(createObj);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(user: any): Promise<EventScheduleEntity[] | Error> {
        const data = await this.eventScheduleRepository.findByFilterQuery({ invitedBy: user.id });
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async findOne(id: string, user: any): Promise<EventScheduleEntity[] | Error> {
        const data: any = await this.eventScheduleRepository.findByFilterQuery({ invitedBy: user.id });
        if (data.length <= 0) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdateEventScheduleDto, user: any): Promise<EventScheduleEntity | Error> {
        const updatedInvite : any = await this.eventScheduleRepository.updateEntity(id, dto);
        if (!updatedInvite) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", updatedInvite);
    }

    async remove(id: string, user: any): Promise<boolean | Error> {
        const data = await this.eventScheduleRepository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                `Failed to delete invitation`,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
