import {Body, Controller, Delete, Get, Param, Patch, Post, Req, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {AuthGuard} from "../../core/guards/auth.guard";
import { NotificationService } from './notification.service';
import { CreateNotificationDto } from './dto/create-notification.dto';
import { UpdateNotificationDto } from "./dto/update-notification.dto";

@Controller({path: 'notification', version: Constants.API_VERSION_1})
export class NotificationController {
    constructor(private readonly service: NotificationService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(@Body() dto: CreateNotificationDto) {
        return this.service.create(dto);
    }

    @Get('userid/:userid')
    @UseGuards(AuthGuard)
    findNotificationsByUserId(@Param('userid') userId: string) {
        return this.service.findNotificationsByUserId(userId);
    }

    @Patch(':id')
    @UseGuards(AuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateNotificationDto) {
        return this.service.update(id, dto);
    }

    // @Delete(':id')
    // @UseGuards(AuthGuard)
    // async remove(@Param('id') id: string, @Req() request: any) {
    //     return await this.service.remove(id, request.user);
    // }
}
