import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreatePartyDto} from "./dto/create-party.dto";
import {UpdatePartyDto} from "./dto/update-party.dto";
import {PartyEntity} from "./entity/party.entity";

@EntityRepository(PartyEntity)
export class PartyRepository extends Repository<PartyEntity> {

    async createEntity(dto: CreatePartyDto): Promise<PartyEntity | Error> {
        try {
            const entity = this.create({...dto});
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PartyEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PartyEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePartyDto): Promise<PartyEntity | Error> {
        try {
            await this.update(id, {...dto});
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async getAllPartyByUserId(id: string) {
        try {
            const sql =
            `SELECT p.*, GROUP_CONCAT(p.userName) as groupName, COUNT(*) memberCount
            FROM party p
            WHERE p.transactionId in
            (SELECT transactionId FROM party WHERE userId = '${id}')
            GROUP BY p.transactionId
            HAVING COUNT(*) > 1;`;

            return await this.manager.query(sql);
        } catch (error) {
            return error;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(PartyEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}